@@ -1,9 +1,7 @@
 package Dist::Zilla::Plugin::TravisCI;
-BEGIN {
-  $Dist::Zilla::Plugin::TravisCI::AUTHORITY = 'cpan:GETTY';
-}
+our $AUTHORITY = 'cpan:GETTY';
 # ABSTRACT: Integrating the generation of .travis.yml into your dzil
-$Dist::Zilla::Plugin::TravisCI::VERSION = '0.008';
+$Dist::Zilla::Plugin::TravisCI::VERSION = '0.009';
 use Moose;
 use Path::Tiny qw( path );
 use Dist::Zilla::File::FromCode;
@@ -24,6 +22,7 @@ has irc_template  => ( is => 'ro', isa => 'ArrayRef[Str]', default => sub { [
 ] } );
 
 has perl_version  => ( is => 'ro', isa => 'ArrayRef[Str]', default => sub { [
+   "5.22",
    "5.20",
    "5.18",
    "5.16",
@@ -196,7 +195,7 @@ Dist::Zilla::Plugin::TravisCI - Integrating the generation of .travis.yml into y
 
 =head1 VERSION
 
-version 0.008
+version 0.009
 
 =head1 SYNOPSIS
 
